@@ -7,8 +7,6 @@ Usage::
 
     data: NotificationPropertyTypeDef = {...}
 """
-from __future__ import annotations
-
 from datetime import datetime
 import sys
 from typing import Dict, List
@@ -191,6 +189,7 @@ __all__ = (
     "ListCrawlersResponseTypeDef",
     "ListDevEndpointsResponseTypeDef",
     "ListJobsResponseTypeDef",
+    "ListMLTransformsResponseTypeDef",
     "ListTriggersResponseTypeDef",
     "ListWorkflowsResponseTypeDef",
     "LocationTypeDef",
@@ -429,6 +428,7 @@ JobTypeDef = TypedDict(
         "ExecutionProperty": ExecutionPropertyTypeDef,
         "Command": JobCommandTypeDef,
         "DefaultArguments": Dict[str, str],
+        "NonOverridableArguments": Dict[str, str],
         "Connections": ConnectionsListTypeDef,
         "MaxRetries": int,
         "AllocatedCapacity": int,
@@ -776,7 +776,7 @@ _RequiredConnectionInputTypeDef = TypedDict(
     "_RequiredConnectionInputTypeDef",
     {
         "Name": str,
-        "ConnectionType": Literal["JDBC", "SFTP"],
+        "ConnectionType": Literal["JDBC", "SFTP", "MONGODB"],
         "ConnectionProperties": Dict[
             Literal[
                 "HOST",
@@ -795,6 +795,7 @@ _RequiredConnectionInputTypeDef = TypedDict(
                 "CUSTOM_JDBC_CERT",
                 "SKIP_CUSTOM_JDBC_CERT_VALIDATION",
                 "CUSTOM_JDBC_CERT_STRING",
+                "CONNECTION_URL",
             ],
             str,
         ],
@@ -1144,7 +1145,7 @@ ConnectionTypeDef = TypedDict(
     {
         "Name": str,
         "Description": str,
-        "ConnectionType": Literal["JDBC", "SFTP"],
+        "ConnectionType": Literal["JDBC", "SFTP", "MONGODB"],
         "MatchCriteria": List[str],
         "ConnectionProperties": Dict[
             Literal[
@@ -1164,6 +1165,7 @@ ConnectionTypeDef = TypedDict(
                 "CUSTOM_JDBC_CERT",
                 "SKIP_CUSTOM_JDBC_CERT_VALIDATION",
                 "CUSTOM_JDBC_CERT_STRING",
+                "CONNECTION_URL",
             ],
             str,
         ],
@@ -1181,7 +1183,7 @@ GetConnectionResponseTypeDef = TypedDict(
 
 GetConnectionsFilterTypeDef = TypedDict(
     "GetConnectionsFilterTypeDef",
-    {"MatchCriteria": List[str], "ConnectionType": Literal["JDBC", "SFTP"]},
+    {"MatchCriteria": List[str], "ConnectionType": Literal["JDBC", "SFTP", "MONGODB"]},
     total=False,
 )
 
@@ -1710,6 +1712,7 @@ JobUpdateTypeDef = TypedDict(
         "ExecutionProperty": ExecutionPropertyTypeDef,
         "Command": JobCommandTypeDef,
         "DefaultArguments": Dict[str, str],
+        "NonOverridableArguments": Dict[str, str],
         "Connections": ConnectionsListTypeDef,
         "MaxRetries": int,
         "AllocatedCapacity": int,
@@ -1738,6 +1741,20 @@ ListJobsResponseTypeDef = TypedDict(
     "ListJobsResponseTypeDef", {"JobNames": List[str], "NextToken": str}, total=False
 )
 
+_RequiredListMLTransformsResponseTypeDef = TypedDict(
+    "_RequiredListMLTransformsResponseTypeDef", {"TransformIds": List[str]}
+)
+_OptionalListMLTransformsResponseTypeDef = TypedDict(
+    "_OptionalListMLTransformsResponseTypeDef", {"NextToken": str}, total=False
+)
+
+
+class ListMLTransformsResponseTypeDef(
+    _RequiredListMLTransformsResponseTypeDef, _OptionalListMLTransformsResponseTypeDef
+):
+    pass
+
+
 ListTriggersResponseTypeDef = TypedDict(
     "ListTriggersResponseTypeDef", {"TriggerNames": List[str], "NextToken": str}, total=False
 )
